announce method
Announces identity as signed in, or null as an authoritative sign-out.
Implementation
void announce(WincheIdentity? identity) {
_identity = identity;
_rotation = 0;
notifyIdentityChanged(identity);
}
Announces identity as signed in, or null as an authoritative sign-out.
void announce(WincheIdentity? identity) {
_identity = identity;
_rotation = 0;
notifyIdentityChanged(identity);
}