skipped property

Map<String, String> skipped
final

Checks that could not run because the caller did not supply the driver they need, with the reason.

Implementation

final Map<String, String> skipped;