WincheContractFailure class final

One contract expectation that an implementation did not meet.

Constructors

WincheContractFailure(String check, String detail)
Creates a failure.
const

Properties

check String
The behaviour that was checked.
final
detail String
What went wrong, in enough detail to act on.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited